@@ -10,4 +10,5 @@ Results = List[Result]
 ResultOrResults = Union[Result, Results]
 StrOrView = Union[str, "ItemView"]
 RunnerArgs = Union[str, List[str], "ItemView", List["ItemView"]]
-IterativeResults = List[Tuple[Tuple[Dict[str, Any], ...], Tuple[Any]]]
\ No newline at end of file
+IterativeResult = Tuple[Tuple[Dict[str, Any], ...], Tuple[Any]]
+IterativeResults = List[IterativeResult]
\ No newline at end of file
